@@ -11,7 +11,7 @@ def get_transaction_trends_html(league_id=139692):
 def parse_row(row):
     # only for use with transaction trend table
     columns = row.select('td')
-    player = columns[0].text.replace('New Player Note').replace('Player Note', '').replace('No new player Notes').replace('\n', '').split('-')[0].strip()
+    player = columns[0].text.replace('New Player Note', '').replace('Player Note', '').replace('No new player Notes', '').replace('\n', '').split('-')[0].strip()
     return {
         'Player': player,
         'Drops': int(columns[1].text),
